Lua_ChaosForestHurtRewardPanel = class("Lua_ChaosForestHurtRewardPanel", Lua_DisplayObject)
function Lua_ChaosForestHurtRewardPanel:ctor(p)
	self:superCall("ctor", p);
end

function Lua_ChaosForestHurtRewardPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rectW = 580;
	self.rectH = 141;
    self.subRectW = self.rectW;
    self.subRectH = 141;
    self.subMinPos = -(self.subRectW - self.rectW) / 2;
    self.subMaxPox = -self.subMinPos;
    self.spaceW = 140;

    self.scrollContainer = UICreate.createScrollContainer(self.content, 0, 0, self.rectW, self.rectH);
    self.scrollContainer.horizontal = true;
    self.scrollContainer.vertical = false;
    self.scrollContainer.movementTypeValue = 1;
    self.scrollContainer.elasticity = 0.3;
    self.scrollContainer.inertia = true;
    self.scrollContainer:setScrollAnchor(0.5, 0.5, 0.5, 0.5);
    self.scrollContainer:setScrollPivot(4);
    self.scrollContainer:addRectMask2D();

    self.sub = self.scrollContainer.scrollContent;
end

function Lua_ChaosForestHurtRewardPanel:dispose()
	if self.hurtArr ~= nil then
		self.hurtArr:dispose();
		self.hurtArr:clear();
		self.hurtArr = nil;
	end
	self.hurtBar = nil;
    self.sub = nil;
    if self.scrollContainer ~= nil then
        self.scrollContainer:dispose();
        self.scrollContainer = nil;
    end
	self:superCall("dispose");
end

function Lua_ChaosForestHurtRewardPanel:updateShowInfo()
	local arr = DataCenter.chaosForestUtil:getHurtRewardShow();
	local dataLen = arr:getSize();

	local barWidth = dataLen * self.spaceW;
	self.subRectW = barWidth + self.spaceW / 2;
	local halfSubRectW = self.subRectW / 2;
	if self.hurtBar == nil then
        self.subMinPos = -(self.subRectW - self.rectW) / 2;
        self.subMaxPox = -self.subMinPos;
		self.scrollContainer:setScrollSize(self.subRectW, self.subRectH);
		self.scrollContainer:setScrollPosition(self.subMaxPox, 0, 0);

		self.hurtBar = UICreate.createProgressBar(self.sub, 
			"chaos_forest_altas", "xui_yasl_Progress _b1", "chaos_forest_altas", "xui_yasl_Progress _f1", 
			-halfSubRectW, -8, barWidth, 11);
		self.hurtBar.pivot = Lua_WindowUtil.getPivot(3);
		self.hurtBar:setBarOffset(4, 2);
	end

	local hurt = DataCenter.chaosForestData.high_hurt;
	local maxValue = arr[dataLen].hurt;
	local value = 0;
	local index = 1;
	if hurt >= maxValue then
		value = maxValue;
	else
		local stepSpace = maxValue / dataLen;
		for i = 1, dataLen do
			if arr[i].hurt >= hurt then
				index = i;
				break;
			end
		end
		value = value + stepSpace * (index - 1);
		local num;
		if index <= 1 then
			num = stepSpace / arr[index].hurt;
			value = value + hurt * num;
		else
			num = stepSpace / (arr[index].hurt - arr[index - 1].hurt);
			value = value + (hurt - arr[index - 1].hurt) * num;
		end
	end
	self.hurtBar:setMaxValue(maxValue);
	self.hurtBar:setValue(value);

	if self.hurtArr == nil then
		self.hurtArr = Array();
	end
	local len = self.hurtArr:getSize();
	local maxLen = dataLen > len and dataLen or len;
	local item;
	local state;
	local index;
	for i = 1, maxLen do
		item = self.hurtArr[i];
		if i > dataLen then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_ChaosForestHurtRewardItem.new(self.sub);
				self.hurtArr:add(item);
			else
				item:setEnable(true);
			end
			item:setLocation(i / dataLen * barWidth - halfSubRectW, -8, 0);
			item:setData(arr[i]);

			state = DataCenter.chaosForestData:getHurtRewardState(arr[i].id);
			if state == 2 then
				index = i;
			end
		end
	end

	index = index or 1;
	self:moveToIndex(index);
end

function Lua_ChaosForestHurtRewardPanel:moveToIndex(idx)
    local targetPos = self.subMaxPox;
    for i = 1, idx - 2 do
        targetPos = targetPos - self.spaceW;
    end

    if targetPos > self.subMaxPox then
        targetPos = self.subMaxPox;
    elseif targetPos < self.subMinPos then
        targetPos = self.subMinPos;
    end
    self.scrollContainer:setScrollPosition(targetPos, 0, 0);
end




















Lua_ChaosForestHurtRewardItem = class("Lua_ChaosForestHurtRewardItem", Lua_DisplayObject);
function Lua_ChaosForestHurtRewardItem:ctor(p)
	self:superCall("ctor", p, "ChaosForestHurtRewardItem_skin");
end

function Lua_ChaosForestHurtRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setLocation(0, 40, 0);
	self.itemIcon:setScale(0.4, 0.4, 1);
	self.itemIcon:setCanClick(true);
end

function Lua_ChaosForestHurtRewardItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self.itemVo = nil;
	self:superCall("dispose");
end

function Lua_ChaosForestHurtRewardItem:setData(data)
	if data == nil then
		return;
	end

	if self.itemVo == nil then
		self.itemVo = Lua_ToolVo.createToolVo(data.reward[1][1]);
	else
		self.itemVo:setData(data.reward[1][1]);
	end
	self.itemIcon:setData(self.itemVo);
	self.itemIcon:showNum(0);
	self:showNum(data.reward[1][2]);

	local state = DataCenter.chaosForestData:getHurtRewardState(data.id);
	self:setDrawMask(state == 2);

	if state == 2 then
		self.icon:setAltas("chaos_forest_altas", "xui_yasl_Progress _f2");
	else
		self.icon:setAltas("chaos_forest_altas", "xui_yasl_Progress-_b2");
	end

	self.hurtValue.text = numberTrans(data.hurt);
end

function Lua_ChaosForestHurtRewardItem:showNum(num)
	if self._txt_right_down == nil then
		self._txt_right_down = UICreate.createLabel(self.content, nil, 20, 25, 100, 31, 18);
		self._txt_right_down.pivot = Lua_WindowUtil.getPivot(5);
		self._txt_right_down.fontName = Lua_MyUISettings.fangzhengFontName;
		self._txt_right_down.alignmentValue = 5;
		self._txt_right_down.horizontalOverflowValue = 1;
		self._txt_right_down.effectStyle = 2;
		self._txt_right_down.colorStr = Lua_ColorDefine.transColor("FFFFFF");
		self._txt_right_down.effectColorStr = Lua_ColorDefine.transColor("463D3A");
		self._txt_right_down:setEffectDistance(2, 2);
	end
	self._txt_right_down.text = num;
end

function Lua_ChaosForestHurtRewardItem:setDrawMask(bState)
	if bState then
		if self.drawMask == nil then
			self.drawMask = UICreate.createUIAtlasImage(self.content, "common_altas_1", "ui_common_window_014", 0, 40, 0, 0);
			self.drawMask:setScale(0.5, 0.5, 1);
		end
		self.drawMask:setEnable(true);
	else
		if self.drawMask ~= nil then
			self.drawMask:setEnable(false);
		end
	end
end